module.exports = defineTest({
	description: 'Properly detect side-effects in generator functions'
});
